lifelib
==========
*Life actuarial models in Python*

.. image:: https://img.shields.io/pypi/pyversions/lifelib
    :target: https://pypi.org/project/lifelib/

.. image:: https://img.shields.io/pypi/v/lifelib
    :target: https://pypi.org/project/lifelib/

.. image:: https://img.shields.io/pypi/l/lifelib
    :target: https://github.com/fumitoh/lifelib/blob/master/LICENSE.txt


What is lifelib?
-------------------

**lifelib** is a collection of open-source life actuarial models.
lifelib includes a variety of models, with sample scripts
and Jupyter notebooks to demonstrate how to use the models.

Visit https://lifelib.io for more information!


What for?
---------

lifelib models are highly versatile and transparent.
You can customize lifelib models and utilize them
in various practical areas, such as:

- Model validation / testing
- Pricing / profit testing
- Research / educational projects
- Valuation / cashflow projections
- Asset-liability modeling
- Risk and capital modeling
- Actuarial modernization to replace spreadsheet models


Why lifelib?
------------

lifelib models are built using `modelx`_, an open-source
Python package for building object-oriented models in Python.
By using lifelib, you can enjoy the following advantages:

* Models run fast!
* Formulas are easy to read
* Easy to trace formula dependency and errors
* Formulas are instantly evaluated
* Pandas and Numpy can be utilized
* Object-oriented
* Input from Excel and CSV files
* Documents can be integrated
* Formulas are saved in text files

Consequently, you can expect following benefits from
model development and governance perspectives:

- More efficient, transparent and faster model development
- Model integration with Python ecosystem (Pandas, Numpy, SciPy, etc..)
- Spreadsheet error elimination
- Better version control / model governance
- Automated model testing

.. _modelx: http://docs.modelx.io


License
-------
Copyright (c) 2021 lifelib Developers

lifelib is free software; you can redistribute it and/or
modify it under the terms of
`MIT License
<https://github.com/fumitoh/lifelib/blob/master/LICENSE.txt>`_.

Contributions, productive comments, requests and feedback from the community
are always welcome. Information on lifelib development is found at Github
https://github.com/fumitoh/lifelib

Requirements
------------
* Python 3.6+
* modelx
* networkx 2.0+
* Pandas
* OpenPyXL

Development State
-----------------
lifelib is in its early alpha-release stage, and its specifications
are subject to change without consideration on backward compatibility.

History
-------
lifelib was originally written by Fumito Hamamura
and it was first released on January 2nd, 2018.

